@@ -20,8 +20,6 @@ import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import exc
 
-from neutron.db import standard_attr
-
 from neutron_lib.api.definitions import bgpvpn as bgpvpn_def
 from neutron_lib.api.definitions import bgpvpn_routes_control as bgpvpn_rc_def
 from neutron_lib.api.definitions import bgpvpn_vni as bgpvpn_vni_def
@@ -29,6 +27,7 @@ from neutron_lib.db import api as db_api
 from neutron_lib.db import constants as db_const
 from neutron_lib.db import model_base
 from neutron_lib.db import model_query
+from neutron_lib.db import standard_attr
 from neutron_lib.db import utils as db_utils
 from neutron_lib.plugins import directory
 
@@ -131,7 +130,7 @@ class BGPVPN(standard_attr.HasStandardAttributes, model_base.BASEV2,
     """Represents a BGPVPN Object."""
     name = sa.Column(sa.String(255))
     type = sa.Column(sa.Enum("l2", "l3",
-                             name="bgpvpn_type"),
+                             name="vpn_types"),
                      nullable=False)
     route_targets = sa.Column(sa.String(255), nullable=False)
     import_targets = sa.Column(sa.String(255), nullable=True)
@@ -167,7 +166,7 @@ class BGPVPNPortAssociationRoute(model_base.BASEV2, model_base.HasId):
         sa.ForeignKey('bgpvpn_port_associations.id', ondelete='CASCADE'),
         nullable=False)
     type = sa.Column(sa.Enum(*bgpvpn_rc_def.ROUTE_TYPES,
-                             name="bgpvpn_port_assoc_route_type"),
+                             name="bgpvpn_port_association_route_type"),
                      nullable=False)
     local_pref = sa.Column(sa.BigInteger(),
                            nullable=True)
