@@ -107,10 +107,10 @@ class Bgpvpn(api_extensions.APIExtensionDescriptor):
         resources = resource_helper.build_resource_info(
             plural_mappings,
             bgpvpn_api_def.RESOURCE_ATTRIBUTE_MAP,
-            bgpvpn_api_def.LABEL,
+            bgpvpn_api_def.ALIAS,
             register_quota=True,
             translate_name=True)
-        plugin = directory.get_plugin(bgpvpn_api_def.LABEL)
+        plugin = directory.get_plugin(bgpvpn_api_def.ALIAS)
         for collection_name in bgpvpn_api_def.SUB_RESOURCE_ATTRIBUTE_MAP:
             # Special handling needed for sub-resources with 'y' ending
             # (e.g. proxies -> proxy)
@@ -135,18 +135,6 @@ class Bgpvpn(api_extensions.APIExtensionDescriptor):
             resources.append(resource)
         return resources
 
-    # TODO(boden): remove with use of I8ae11633962a48de6e8559b85447b8c8c753d705
-    @classmethod
-    def get_extended_resources(cls, version):
-        # we need to declare these extensions here so that they can be extended
-        # by the bgpvpn-routes-control extension
-        if version == "2.0":
-            return dict(list(bgpvpn_api_def.RESOURCE_ATTRIBUTE_MAP.items()) +
-                        list(bgpvpn_api_def.SUB_RESOURCE_ATTRIBUTE_MAP.items())
-                        )
-        else:
-            return {}
-
     @classmethod
     def get_plugin_interface(cls):
         return BGPVPNPluginBase
@@ -158,11 +146,8 @@ class BGPVPNPluginBase(libbase.ServicePluginBase):
     path_prefix = "/" + bgpvpn_api_def.ALIAS
     supported_extension_aliases = [bgpvpn_api_def.ALIAS]
 
-    def get_plugin_name(self):
-        return bgpvpn_api_def.LABEL
-
     def get_plugin_type(self):
-        return bgpvpn_api_def.LABEL
+        return bgpvpn_api_def.ALIAS
 
     def get_plugin_description(self):
         return 'BGP VPN Interconnection service plugin'
