@@ -54,6 +54,11 @@ class BGPVPNPortAssocRouteWrongBGPVPNTenant(n_exc.BadRequest):
                 "(%(bgpvpn_id)s)")
 
 
+class BGPVPNPortAssocRouteBGPVPNTypeDiffer(n_exc.BadRequest):
+    message = _("bgpvpn specified in route is of type %(route_bgpvpn_type)s, "
+                "differing from type of associated BGPVPN %(bgpvpn_type)s)")
+
+
 class Bgpvpn_routes_control(api_extensions.APIExtensionDescriptor):
 
     api_definition = api_def
@@ -62,7 +67,7 @@ class Bgpvpn_routes_control(api_extensions.APIExtensionDescriptor):
     def get_resources(cls):
         """Returns Ext Resources."""
         # the plugin we link this extension with is the 'bgpvpn' plugin:
-        plugin = directory.get_plugin(bgpvpn_api.LABEL)
+        plugin = directory.get_plugin(bgpvpn_api.ALIAS)
 
         # The port association is the only new (sub-)resource
         # introduced by the bgpvpn-routes-control extension
@@ -89,17 +94,6 @@ class Bgpvpn_routes_control(api_extensions.APIExtensionDescriptor):
 
         return [port_association_resource]
 
-    # TODO(boden): remove with use of I8ae11633962a48de6e8559b85447b8c8c753d705
-    @classmethod
-    def get_extended_resources(cls, version):
-        if version == "2.0":
-            return dict(
-                list(api_def.RESOURCE_ATTRIBUTE_MAP.items()) +
-                list(api_def.SUB_RESOURCE_ATTRIBUTE_MAP.items())
-            )
-        else:
-            return {}
-
     @classmethod
     def get_plugin_interface(cls):
         return BGPVPNRoutesControlPluginBase
