@@ -17,7 +17,6 @@ from sqlalchemy import orm
 
 from neutron.api.rpc.callbacks import events as rpc_events
 from neutron.api.rpc.handlers import resources_rpc
-from neutron.db import api as db_api
 from neutron.db.models import external_net
 
 from neutron_lib.api.definitions import bgpvpn_routes_control as bgpvpn_rc_def
@@ -25,9 +24,12 @@ from neutron_lib.api.definitions import bgpvpn_vni as bgpvpn_vni_def
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
+from neutron_lib.db import api as db_api
 from neutron_lib import exceptions as n_exc
 from neutron_lib.plugins import directory
 
+from networking_bagpipe.objects import bgpvpn as bgpvpn_objects
+
 from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 
@@ -35,7 +37,6 @@ from networking_bgpvpn.neutron.extensions import bgpvpn as bgpvpn_ext
 from networking_bgpvpn.neutron.services.common import utils
 from networking_bgpvpn.neutron.services.service_drivers import driver_api
 
-from networking_bagpipe.objects import bgpvpn as bgpvpn_objects
 
 LOG = logging.getLogger(__name__)
 
@@ -48,7 +49,7 @@ class BGPVPNExternalNetAssociation(n_exc.NeutronException):
                 "network to a BGPVPN")
 
 
-@db_api.context_manager.reader
+@db_api.CONTEXT_READER
 def network_is_external(context, net_id):
     try:
         context.session.query(external_net.ExternalNetwork).filter_by(
@@ -69,6 +70,7 @@ def _log_callback_processing_exception(resource, event, trigger, kwargs, e):
                    'exc': e})
 
 
+@registry.has_registry_receivers
 class BaGPipeBGPVPNDriver(driver_api.BGPVPNDriverRC):
 
     """BGPVPN Service Driver class for BaGPipe"""
@@ -79,16 +81,6 @@ class BaGPipeBGPVPNDriver(driver_api.BGPVPNDriverRC):
     def __init__(self, service_plugin):
         super(BaGPipeBGPVPNDriver, self).__init__(service_plugin)
 
-        registry.subscribe(self.registry_router_interface_created,
-                           resources.ROUTER_INTERFACE,
-                           events.AFTER_CREATE)
-
-        # need to subscribe to router interface *before*_delete,
-        # because after, we can't build the OVO objects from the DB anymore
-        registry.subscribe(self.registry_router_interface_before_delete,
-                           resources.ROUTER_INTERFACE,
-                           events.BEFORE_DELETE)
-
         self._push_rpc = resources_rpc.ResourcesPushRpcApi()
 
     def _push_association(self, context, association, event_type):
@@ -233,6 +225,7 @@ class BaGPipeBGPVPNDriver(driver_api.BGPVPNDriverRC):
 
         self._push_associations(context, associations, rpc_events.UPDATED)
 
+    @registry.receives(resources.ROUTER_INTERFACE, [events.AFTER_CREATE])
     @log_helpers.log_method_call
     def registry_router_interface_created(self, resource, event, trigger,
                                           **kwargs):
@@ -245,21 +238,25 @@ class BaGPipeBGPVPNDriver(driver_api.BGPVPNDriverRC):
             _log_callback_processing_exception(resource, event, trigger,
                                                kwargs, e)
 
+    # need to subscribe to router interface *before*_delete
+    # because after delete, we can't build the OVO objects from the DB anymore
+    @registry.receives(resources.ROUTER_INTERFACE, [events.BEFORE_DELETE])
     @log_helpers.log_method_call
-    def registry_router_interface_before_delete(self, resource, event, trigger,
-                                                **kwargs):
+    def registry_router_interface_deleted(self, resource, event, trigger,
+                                          payload=None):
         try:
-            context = kwargs['context']
+            context = payload.context
             # for router_interface after_delete, in stable/newton, the
             # callback does not include the router_id directly, but we find
             # it in the port device_id
-            router_id = kwargs['router_id']
-            subnet_id = kwargs['subnet_id']
+            router_id = payload.resource_id
+            subnet_id = payload.metadata['subnet_id']
             # find the network for this subnet
             network_id = directory.get_plugin().get_subnet(
                 context, subnet_id)['network_id']
             self.notify_router_interface_deleted(
                 context, router_id, network_id)
         except Exception as e:
-            _log_callback_processing_exception(resource, event, trigger,
-                                               kwargs, e)
+            _log_callback_processing_exception(
+                resource, event, trigger,
+                {'subnet_id': subnet_id, 'router_id': router_id}, e)
